@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.888';
+our $VERSION = '1.890';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -128,6 +128,9 @@ sub _make_tmpdir {
          $_tmp_base_dir = $ENV{TEMP};
       }
    }
+   elsif (! -w '/tmp' && -e $ENV{TMPDIR} && -d $ENV{TMPDIR} && -w _) {
+      $_tmp_base_dir = $ENV{TMPDIR};
+   }
    else {
       $_tmp_base_dir = ($_use_dev_shm && -d '/dev/shm' && -w _)
          ? '/dev/shm' : '/tmp';
@@ -442,7 +445,7 @@ MCE::Signal - Temporary directory creation/cleanup and signal handling
 
 =head1 VERSION
 
-This document describes MCE::Signal version 1.888
+This document describes MCE::Signal version 1.890
 
 =head1 SYNOPSIS
 
